@@ -1,4 +1,4 @@
-#HEADER
+# HEADER
 #                      arg/Backend/argBackendBase.py
 #               Automatic Report Generator (ARG) v. 1.0
 #
@@ -34,22 +34,24 @@
 #
 # Questions? Visit gitlab.com/AutomaticReportGenerator/arg
 #
-#HEADER
+# HEADER
 
 import abc
 import datetime
 import os
 import shutil
 import sys
-
 import yaml
 
-from arg.Aggregation import argSummarize
 from arg.Common.argInformationObject import argInformationObject
 from arg.Common.argMultiFontStringHelper import argMultiFontStringHelper
+from arg.Aggregation import argExodusAggregator, argVTKSTLAggregator
 
 
 class argBackendBase:
+    """A backend abstractbase class
+    """
+
     __metaclass__ = abc.ABCMeta
 
     @abc.abstractmethod
@@ -140,6 +142,12 @@ class argBackendBase:
         """Generate back-end specific string from matrix entries
         """
 
+    @abc.abstractmethod
+    def add_comment(self, comments_dict, key):
+        """Add comment to the report from a dict as either text string
+        or as sub-paragraph depending on number of dict values (1 or 2)
+        """
+
     @abc.abstractmethod
     def add_paragraph(self, item):
         """Add paragraph to the report
@@ -155,6 +163,11 @@ class argBackendBase:
         """Add subsection to the report
         """
 
+    @abc.abstractmethod
+    def add_subsubsection(self, item, numbered=True):
+        """ Add sub-subsection to the report
+        """
+
     @abc.abstractmethod
     def add_section(self, item, numbered=True):
         """Add section to the report
@@ -170,6 +183,11 @@ class argBackendBase:
         """Add page break to the report
         """
 
+    @abc.abstractmethod
+    def add_color_table(self, data: dict) -> None:
+        """ Add colored table to the report
+        """
+
     @abc.abstractmethod
     def add_table(self, header, body, do_verbatim, position):
         """Add table to the report
@@ -286,7 +304,7 @@ class argBackendBase:
                 file_name = os.path.splitext(file_name)[0]
 
             # Create table of topological properties
-            header_list, body_dict = argSummarize.summarize_exodus_topology(meta_info)
+            header_list, body_dict = data.summarize(type="topology")
             caption_string = argMultiFontStringHelper(self)
             caption_string.append("Topological properties of ", "default")
             caption_string.append(file_name, "typewriter")
@@ -294,7 +312,7 @@ class argBackendBase:
 
             # Create table of mesh blocks if requested and at least one exists
             if verbosity > self.VerbosityLevels.get("terse"):
-                header_list, body_dict = argSummarize.summarize_exodus_blocks(meta_info)
+                header_list, body_dict = data.summarize(type="blocks")
                 if header_list:
                     caption_string.clear()
                     caption_string.append("Element blocks of ", "default")
@@ -304,7 +322,7 @@ class argBackendBase:
             # Create table of node and side sets if requested and at least one exists
             if verbosity > self.VerbosityLevels.get("terse"):
                 for set_type in ("node", "side"):
-                    header_list, body_dict = argSummarize.summarize_exodus_sets(meta_info, set_type)
+                    header_list, body_dict = data.summarize(type="sets", set_type=set_type)
                     if header_list:
                         caption_string.clear()
                         caption_string.append(set_type.title(), "default")
@@ -313,7 +331,7 @@ class argBackendBase:
                         self.add_table(header_list, body_dict, caption_string, True)
 
             # Create table of variables if some are present
-            header_list, body_list = argSummarize.summarize_exodus_variable(meta_info)
+            header_list, body_list = data.summarize(type="variable")
             if body_list:
                 caption_string.clear()
                 caption_string.append("Variables of ", "default")
@@ -321,7 +339,7 @@ class argBackendBase:
                 self.add_table(header_list, body_list, caption_string, True)
 
     def add_information(self, item):
-        """Print information about given property to report and
+        """Add information about given property to report and
            restrict information to specific items if provided
         """
 
@@ -411,8 +429,8 @@ class argBackendBase:
             tab_head[0].append(prop_type, "typewriter")
             tab_head += [argMultiFontStringHelper(self)
                          for _ in prop_items]
-            map(lambda x, p: x.append(p, "typewriter"),
-                tab_head[1:], prop_items)
+            for p in prop_items:
+                tab_head.append(p)
             multi_font_string = argMultiFontStringHelper(self)
             multi_font_string.append("Values of ", "default")
             multi_font_string.append(prop_type, "typewriter")
@@ -452,6 +470,24 @@ class argBackendBase:
                             multi_font_string,
                             True)
 
+    def add_aggregation(self, item):
+        """Add information aggregated from various backends
+        """
+
+        # Choose aggregator depending on data type
+        data_type = item.get("datatype")
+        if data_type == "ExodusII":
+            # Instantiate ExodusII aggregator on self and execute it
+            aggregator = argExodusAggregator.argExodusAggregator(self, item)
+            aggregator.aggregate()
+        elif data_type == "vtkSTL":
+            # Instantiate vtkSNL aggregator on self and execute it
+            aggregator = argVTKSTLAggregator.argVTKSTLAggregator(self, item)
+            aggregator.aggregate()
+        else:
+            # Unsupported data type
+            print("[argBackendBase] Unknown aggregation data type: {}")
+
     def fetch_image_and_caption(self, arguments):
         """Retrieve image and associated caption for figure creation
         """
@@ -511,3 +547,32 @@ class argBackendBase:
 
         # Return retrieve image file name
         return figure_file_name, caption_string
+
+    def parse_headers(self, headers: list) -> list:
+        """ Parses headers for color-table
+        """
+        ccp = self._CELL_PROPS
+        headers_list = [(cell.get(ccp[0], ''), cell.get(ccp[1], ''), cell.get(ccp[2], ''), cell.get(ccp[3], ''),
+                         cell.get(ccp[4], '')) for cell in headers]
+        return headers_list
+
+    def parse_rows(self, rows: list, table_columns_num: int) -> list:
+        """ Parses rows for color-table
+        """
+        rows_list = list()
+        ccp = self._CELL_PROPS
+        for row in rows:
+            row_list = [(cell.get(ccp[0], ''), cell.get(ccp[1], ''), cell.get(ccp[2], ''), cell.get(ccp[3], ''),
+                         cell.get(ccp[4], '')) for cell in row]
+            if len(row) == table_columns_num:
+                rows_list.append(row_list)
+            elif len(row) < table_columns_num:
+                empty_cells = [('', '', '', '', '') for _ in range(table_columns_num - len(row))]
+                row_list.extend(empty_cells)
+                rows_list.append(row_list)
+            else:
+                raise Exception('Too many columns in a row!')
+        return rows_list
+
+    _CELL_PROPS = {0: 'value', 1: 'background-color', 2: 'foreground-color', 3: 'horizontal-alignment',
+                   4: 'vertical-alignment'}
