@@ -46,9 +46,8 @@ import pylatex as pl
 import yaml
 from pylatex.utils import NoEscape, bold, italic, verbatim
 
-from arg.Aggregation import argAggregate
-from arg.Backend.argBackendBase import argBackendBase
 from arg.Common.argMultiFontStringHelper import argMultiFontStringHelper
+from arg.Backend.argBackendBase import argBackendBase
 
 # Load supported colors
 common_dir = os.path.dirname(os.path.realpath(__file__))
@@ -130,11 +129,25 @@ class argLaTeXBackend(argBackendBase):
     def __init__(self, parameters=None):
 
         # Call superclass init
-        super(argLaTeXBackend, self).__init__(parameters)
+        super().__init__(parameters)
 
         # Define backend type
         self.Type = "LaTeX"
 
+        self.colors = None
+        self.__init_colors()
+
+    def __init_colors(self):
+        # Load supported colors
+        common_dir = os.path.dirname(os.path.realpath(__file__))
+        with open(os.path.join(common_dir, "../Common/argTypes.yml"),
+                  'r',
+                  encoding="utf-8") as t_file:
+            supported_types = yaml.safe_load(t_file)
+
+        # Retrieve supported verbosity levels
+        self.colors = supported_types.get("FontColors")
+
     def create_document_preamble(self, version=None):
         """Create document and its preamble given an Assembler version
         """
@@ -170,6 +183,27 @@ class argLaTeXBackend(argBackendBase):
         # No paragraph indentation
         self.Report.change_length(r"\parindent", "0pt")
 
+    def add_comment(self, comments_dict, key):
+        """Add comment to the report from a dict as either text string
+        or as sub-paragraph depending on number of dict values (1 or 2)
+        """
+
+        # Retrieve comment for given key and bail out if none found
+        comment = comments_dict.get(str(key))
+        if not comment:
+            return False
+
+        # Insert either sub-paragraph or string
+        if len(comment) > 1:
+            self.Report.append(
+                pl.Command("subparagraph", comment[0] + ":"))
+            self.Report.append(NoEscape(comment[1]))
+        else:
+            self.Report.append(NoEscape(comment[0]))
+
+        # Comment was found and inserted
+        return True
+
     def add_packages(self):
         """Add LaTeX packages
         """
@@ -201,12 +235,23 @@ class argLaTeXBackend(argBackendBase):
         # Allow for slanted looking fractions
         self.Report.preamble.append(pl.Command("usepackage", "xfrac"))
 
+        # Allow for colored table
+        self.Report.preamble.append(pl.Command("usepackage", "colortbl"))
+
+        # Allow subsubsection
+        self.Report.preamble.append(NoEscape(r"\setcounter{tocdepth}{3}"))
+        self.Report.preamble.append(NoEscape(r"\setcounter{secnumdepth}{3}"))
+
         # Fix problems with underscores
         self.Report.preamble.append(pl.Command("usepackage", "underscore", "strings"))
 
         # Handle path with url package
         self.Report.preamble.append(pl.Command("usepackage", "url", ["obeyspaces", "spaces"]))
 
+        # Allow for hyperlink
+        self.Report.preamble.append(pl.Command("usepackage", "hyperref", ["hidelinks"]))
+        self.Report.preamble.append(pl.Command("hypersetup", "colorlinks=true, urlcolor=blue, filecolor=blue, linkcolor=black"))
+
     def generate_details(self):
         """Generate details: title, organization, address, authors, numbers, etc.
         """
@@ -370,9 +415,9 @@ class argLaTeXBackend(argBackendBase):
                     string = r"\texttt{{{}}}".format(string)
                 if font_bits & 8 == 8:
                     string = r"$\mathcal{{{}}}$".format(string)
-                if color and colors.get(color):
+                if color and self.colors.get(color):
                     sep = ','
-                    rgb = colors.get(color).split(sep)
+                    rgb = self.colors.get(color).split(sep)
                     string = r"\color[rgb]{{{}, {}, {}}}{}".format(int(rgb[0]) / 255.,
                                                                    int(rgb[1]) / 255.,
                                                                    int(rgb[2]) / 255.,
@@ -422,44 +467,24 @@ class argLaTeXBackend(argBackendBase):
             for items in item.get("items"):
                 enum_it.add_item(NoEscape(items.get("string")))
 
-    def add_comment(self, comments, key):
-        """Add text comment from a dict of comments, either as a text
-           string or as a sub-paragraph depending on number of comment
-           parameters (1 or 2)
-        """
-        # Retrieve comment for given key and bail out if none found
-        comment = comments.get(str(key))
-        if not comment:
-            return False
-
-        # Insert either sub-paragraph or string
-        if len(comment) > 1:
-            self.Report.append(pl.Command("subparagraph", comment[0] + ":"))
-            self.Report.append(NoEscape(comment[1]))
-        else:
-            self.Report.append(NoEscape(comment[0]))
-
-        # Comment was found and inserted
-        return True
-
     def add_paragraph(self, item):
         """Add paragraph to the report
         """
-
         # Insert new paragraph
         self.Report.append(pl.Command("par"))
 
+        if "hyperlink_path" in item:
+            hyperlink_path = item.get('hyperlink_path', None)
+            hyperlink_string = item.get('hyperlink_string', None)
+            if "string" in item:
+                self.support_string(item=item)
+                self.Report.append(NoEscape(r"\\"))
+            self.Report.append(NoEscape(r"\href{" + hyperlink_path + r"}{\underline{" + hyperlink_string + r"}}"))
+            self.Report.append(NoEscape(r"\\"))
+
         # Check whether a string or a file is to be included
-        if "string" in item:
-            # Retrieve provided string
-            string = item["string"]
-
-            # Decorate multi-font strings with LaTeX markup
-            if isinstance(string, argMultiFontStringHelper):
-                string = self.generate_multi_font_string(string)
-
-            # Insert string into the report
-            self.Report.append(NoEscape(string))
+        elif "string" in item:
+            self.support_string(item=item)
 
         # Insert verbatim fragment
         elif "verbatim" in item:
@@ -523,6 +548,13 @@ class argLaTeXBackend(argBackendBase):
         # Call appropriate subdivision method
         self.add_subdivision(item, '*')
 
+    def add_subsubsection(self, item, numbered=True):
+        """Add subsubsection to the report
+        """
+
+        # Call appropriate subsubdivision method
+        self.add_subdivision(item, "subsubsection" + ('' if numbered else '*'))
+
     def add_subsection(self, item, numbered=True):
         """Add subsection to the report
         """
@@ -602,7 +634,7 @@ class argLaTeXBackend(argBackendBase):
 
         # Create table
         tab_format = "@{}l" + (n_cols - 1) * 'r' + "@{}"
-        with self.Report.create(pl.LongTable(tab_format)) as table:
+        with self.Report.create(pl.LongTable(table_spec=tab_format, pos=pos)) as table:
             # Create table header
             table.append(NoEscape(r"\toprule"))
             header_list = [decorator(x) for x in header_list]
@@ -674,6 +706,74 @@ class argLaTeXBackend(argBackendBase):
                         "caption",
                         NoEscape(caption_string.execute_backend())))
 
+    def add_color_table(self, data: dict) -> None:
+        """ Add colored table to the report
+        """
+        headers_list = data.get('headers', None)
+        table_columns_num = len(headers_list)
+        rows_list = data.get('rows', None)
+        caption = data.get('caption', None)
+        if headers_list is None or rows_list is None:
+            raise Exception('No headers or rows given!')
+        headers = self.parse_headers(headers=headers_list)
+        rows = self.parse_rows(rows=rows_list, table_columns_num=table_columns_num)
+        headers_len = sum(len(header[0]) for header in headers)
+        max_rows_len = max([sum(len(cell[0]) for cell in row) for row in rows])
+        max_table_len = table_columns_num + max([headers_len, max_rows_len])
+
+        if max_table_len > 50:
+            if max_table_len > 80:
+                if max_table_len > 110:
+                    row_size = NoEscape(r"\tiny")
+                else:
+                    row_size = NoEscape(r"\scriptsize")
+            else:
+                row_size = NoEscape(r"\footnotesize")
+        else:
+            row_size = NoEscape(r"\normalsize")
+
+        # Create function to generate decorated strings when needed
+        dec = lambda x: NoEscape(x.execute_backend()) if isinstance(x, argMultiFontStringHelper) else x
+
+        # Create table
+        tab_format = self.get_table_format(headers=headers)
+        with self.Report.create(pl.LongTable(table_spec=tab_format, pos="ht!")) as table:
+            def color_decoder(rgb_color: str, text: str = 'cellcolor') -> str:
+                if rgb_color == '' and text == 'cellcolor':
+                    return f"\\" + f"{text}" + r"[rgb]{1,1,1} "
+                elif rgb_color == '' and text == 'color':
+                    return f"\\" + f"{text}" + r"[rgb]{0,0,0} "
+                else:
+                    rgb = ','.join([str(int(color) / 255.0) for color in rgb_color.split(',')])
+                    return f"\\" + f"{text}" + r"[rgb]{" + f"{rgb}" + r"} "
+
+            # Create table header
+            table.append(NoEscape(r"\toprule"))
+            header_list = [NoEscape(
+                rf"{color_decoder(rgb_color=x[2], text='color')}{row_size}{color_decoder(rgb_color=x[1])}{dec(x[0])}")
+                           for x in headers]
+            table.add_row(header_list)
+            table.append(NoEscape(r"\midrule\endfirsthead"))
+
+            # Iterate over rows
+            for row in rows:
+                table.add_row([NoEscape(
+                    rf"{color_decoder(rgb_color=x[2], text='color')}{row_size}{color_decoder(rgb_color=x[1])}{dec(x[0])}")
+                               for x in row])
+
+            # Create table footer
+            table.append(NoEscape(r"\bottomrule\\"))
+
+            # Create table caption
+            if caption is not None:
+                if isinstance(caption, str):
+                    # Directly insert base strings
+                    table.append(pl.Command("caption", NoEscape(caption)))
+
+                elif isinstance(caption, argMultiFontStringHelper):
+                    # Insert LaTeX string created from multi-font string
+                    table.append(pl.Command("caption", NoEscape(caption.execute_backend())))
+
     def add_figure(self, arguments):
         """Add figure to the report
         """
@@ -738,6 +838,11 @@ class argLaTeXBackend(argBackendBase):
                 # Create subsection
                 self.add_subsection(item, is_numbered)
 
+            # Handle subsubsection case
+            elif item_type.startswith("subsubsection"):
+                # Create subsubsection
+                self.add_subsubsection(item, is_numbered)
+
             # Handle paragraph case
             elif item_type == "paragraph":
                 # Add paragraph to the report
@@ -774,10 +879,20 @@ class argLaTeXBackend(argBackendBase):
                 # Append information specific to given property to the report
                 self.add_information(item)
 
-            # Handle aggregation case
+            # Handle aggregate case
             elif item_type == "aggregate":
-                # Execute aggregate operation
-                argAggregate.arg_aggregate(self, item)
+                # Append aggregated information
+                self.add_aggregation(item)
+
+            # Handle color-table
+            elif item_type == "color-table":
+                # Append color-table
+                self.add_color_table(data=item)
+
+            # Handle hyperlink
+            elif item_type == "hyperlink":
+                # Append a hyperlink
+                self.add_hyperlink(data=item)
 
             # Proceed with recursion if needed
             if "sections" in item:
@@ -857,3 +972,33 @@ class argLaTeXBackend(argBackendBase):
         self.Report.append(pl.Command("tableofcontents"))
         self.Report.append(pl.Command("listoffigures"))
         self.Report.append(pl.Command("listoftables"))
+
+    def support_string(self, item: dict) -> None:
+        """ Function created in order not to DRY
+        """
+        # Retrieve provided string
+        string = item["string"]
+
+        # Decorate multi-font strings with LaTeX markup
+        if isinstance(string, argMultiFontStringHelper):
+            string = self.generate_multi_font_string(string)
+
+        # Insert string into the report
+        self.Report.append(NoEscape(string))
+
+    @staticmethod
+    def get_table_format(headers: list) -> str:
+        """ Returns table format based on headers
+        """
+        last_num = len(headers) - 1
+        hor_al = list()
+        for num, header in enumerate(headers):
+            if num == 0:
+                a_l = 'l' if header[3] == '' else header[3]
+                hor_al.append('@{}' + a_l)
+            else:
+                a_l = 'r' if header[3] == '' else header[3]
+                hor_al.append(a_l)
+        hor_al.append('@{}')
+        return ''.join(hor_al)
+
