@@ -1,4 +1,4 @@
-#HEADER
+# HEADER
 #                      arg/Backend/argWordBackend.py
 #               Automatic Report Generator (ARG) v. 1.0
 #
@@ -34,7 +34,7 @@
 #
 # Questions? Visit gitlab.com/AutomaticReportGenerator/arg
 #
-#HEADER
+# HEADER
 
 import numbers
 import os
@@ -44,17 +44,16 @@ import subprocess
 
 import clr
 import yaml
+import docx
+from docx.opc.constants import RELATIONSHIP_TYPE as RT
 from docx.enum.text import WD_PARAGRAPH_ALIGNMENT as WD_ALIGN_PARAGRAPH
-from docx.oxml import OxmlElement
-from docx.oxml.ns import qn
+from docx.oxml import OxmlElement, parse_xml
+from docx.oxml.ns import qn, nsdecls
 from docx.shared import Mm, Cm, Inches, RGBColor, Pt
 from pylatex import NoEscape
 
-from arg.Aggregation import argAggregate
-from arg.Backend.argBackendBase import argBackendBase
 from arg.Common.argMultiFontStringHelper import argMultiFontStringHelper
-
-app = "argWordBackend"
+from arg.Backend.argBackendBase import argBackendBase
 
 osn = os.name
 
@@ -150,6 +149,41 @@ class argWordBackend(argBackendBase):
         # Define backend type
         self.Type = "Word"
 
+        self.colors = None
+        self.fonts = None
+        self.app = "argWordBackend"
+        self.osn = os.name
+
+        # Try importing Word Application in Python environment
+        try:
+            clr.AddReference("System")
+            clr.AddReference("Microsoft.Office.Interop")
+            from Microsoft.Office.Interop import Word
+
+        # Find work-around
+        except:
+            try:
+                # Use Windows32 client on Windows only
+                if self.osn == "nt":
+                    from win32com.client import DispatchEx
+            except:
+                pass
+        self.__init_fonts_colors()
+
+    def __init_fonts_colors(self):
+        # Load supported colors
+        common_dir = os.path.dirname(os.path.realpath(__file__))
+        with open(os.path.join(common_dir, "../Common/argTypes.yml"),
+                  'r',
+                  encoding="utf-8") as t_file:
+            supported_types = yaml.safe_load(t_file)
+
+        # Retrieve supported colors
+        self.colors = supported_types.get("FontColors")
+
+        # Retrieve supported fonts
+        self.fonts = supported_types.get("BackendTypes").get("Word").get("Fonts")
+
     @staticmethod
     def generate_text(text, type="default"):
         """Add page break to the report
@@ -177,13 +211,13 @@ class argWordBackend(argBackendBase):
                 run.italic = font_bits & 1 == 1
                 run.bold = font_bits & 2 == 2
                 if font_bits & 4 == 4:
-                    run.font.name = fonts.get("typewriter", "default" if fonts.get("default") else None)
+                    run.font.name = self.fonts.get("typewriter", "default" if self.fonts.get("default") else None)
                 elif font_bits & 8 == 8:
-                    run.font.name = fonts.get("calligraphic", "default" if fonts.get("default") else None)
-                elif fonts.get("default", None):
-                    run.font.name = fonts.get("default", None)
+                    run.font.name = self.fonts.get("calligraphic", "default" if self.fonts.get("default") else None)
+                elif self.fonts.get("default", None):
+                    run.font.name = self.fonts.get("default", None)
                 if color:
-                    rgb = colors.get(color).split(',')
+                    rgb = self.colors.get(color).split(',')
                     if len(rgb) > 2:
                         run.font.color.rgb = RGBColor(*[int(x) for x in rgb[:3]])
 
@@ -245,20 +279,20 @@ class argWordBackend(argBackendBase):
             if "number" in it.keys():
                 self.Report.add_paragraph(it["number"])
 
-    def add_comment(self, comments, key):
-        """Add text comment from a dict of comments, either as a text
-           string or as a sub-paragraph depending on number of comment
-           parameters (1 or 2)
+    def add_comment(self, comments_dict, key):
+        """Add comment to the report from a dict as either text string
+        or as sub-paragraph depending on number of dict values (1 or 2)
         """
 
         # Retrieve comment for given key and bail out if none found
-        comment = comments.get(str(key))
+        comment = comments_dict.get(str(key))
         if not comment:
             return False
 
         # Insert either sub-paragraph or string
         if len(comment) > 1:
-            self.Report.add_paragraph(comment[0] + ":", "Subtitle")
+            self.Report.add_paragraph(
+                comment[0] + ":", "Subtitle")
             self.Report.add_paragraph(comment[1])
         else:
             self.Report.add_paragraph(comment[0])
@@ -269,20 +303,18 @@ class argWordBackend(argBackendBase):
     def add_paragraph(self, item, p=None):
         """Add paragraph to the report
         """
+        if "hyperlink_path" in item:
+            hyperlink_path = item.get('hyperlink_path', None)
+            hyperlink_string = item.get('hyperlink_string', None)
+            if "string" in item:
+                self.support_string(item=item)
+            par = p if p is not None else self.Report.add_paragraph()
+            self.add_hyperlink_to_paragraph(paragraph=par, url=hyperlink_path, text=hyperlink_string, color='0000FF',
+                                            underline=True)
 
         # Check whether a string or a file is to be included
-        if "string" in item:
-            # Retrieve provided string
-            string = item["string"]
-
-            # Distinguish between plain and multi-font strings
-            if isinstance(string, argMultiFontStringHelper):
-                # Insert string into the report
-                self.generate_multi_font_string(
-                    string, self.Report.add_paragraph())
-            else:
-                # Directly insert Word fragment into the report
-                self.Report.add_paragraph(string)
+        elif "string" in item:
+            self.support_string(item=item)
 
         # Insert verbatim fragment
         elif "verbatim" in item:
@@ -328,9 +360,9 @@ class argWordBackend(argBackendBase):
 
                 # Add font commands if provided
                 if font == "typewriter":
-                    run.font.name = fonts.get(font, "default" if fonts.get("default") else None)
+                    run.font.name = self.fonts.get(font, "default" if self.fonts.get("default") else None)
                 elif font == "calligraphic":
-                    run.font.name = fonts.get(font, "default" if fonts.get("default") else None)
+                    run.font.name = self.fonts.get(font, "default" if self.fonts.get("default") else None)
                 if size:
                     run.font.size = Pt(size)
                 if italic:
@@ -386,6 +418,13 @@ class argWordBackend(argBackendBase):
         # Call appropriate subdivision method
         self.add_subdivision(item, 3)
 
+    def add_subsubsection(self, item, numbered=True):
+        """Add subsection to the report
+        """
+
+        # Call appropriate subdivision method
+        self.add_subdivision(item, 4)
+
     def add_subsection(self, item, numbered=True):
         """Add subsection to the report
         """
@@ -429,7 +468,7 @@ class argWordBackend(argBackendBase):
         else:
             self.Report.add_heading(text, lvl)
 
-    def add_table(self, header_list, body, caption_string, do_verbatim=False, pos='t'):
+    def add_table(self, header_list, body, caption_string, do_verbatim=False, _=None):
         """Add table to the report
         """
 
@@ -542,6 +581,102 @@ class argWordBackend(argBackendBase):
             # Insert blank paragraph to ensure table is closed
             self.Report.add_paragraph()
 
+    def add_color_table(self, data: dict) -> None:
+        """ Add colored table to the report
+        """
+
+        headers_list = data.get('headers', None)
+        table_columns_num = len(headers_list)
+        rows_list = data.get('rows', None)
+        caption_string = data.get('caption', None)
+        if headers_list is None or rows_list is None:
+            raise Exception('No headers or rows given!')
+        headers = self.parse_headers(headers=headers_list)
+        rows = self.parse_rows(rows=rows_list, table_columns_num=table_columns_num)
+
+        # Create table with required number of columns
+        table = self.Report.add_table(rows=1, cols=table_columns_num)
+        table.alignment = WD_ALIGN_PARAGRAPH.CENTER
+
+        # Create table header
+        cells = table.rows[0].cells
+        for c, header_string, font_color, alignment in \
+                zip(cells, [header[0] for header in headers],
+                    [self.parse_rgb_to_hex(rgb=header[2], appl=2) for header in headers],
+                    [self.parse_cell_align(align=header[3]) for header in headers]):
+            # Fill header cell
+            if isinstance(header_string, str):
+                # Directly insert base strings
+                c.paragraphs[0].add_run(header_string).font.color.rgb = RGBColor.from_string(f"{font_color}")
+                c.paragraphs[0].alignment = alignment
+
+
+            elif isinstance(header_string, argMultiFontStringHelper):
+                # Handle multi-font string helpers
+                self.generate_multi_font_string(header_string, c.paragraphs[0])
+
+        # Iterate over of contents to create table body
+
+        # Iterate over list entries
+        for row in rows:
+            # Add a row of cells and fill those
+            cells = table.add_row().cells
+            for c, cell_string, font_color, alignment in \
+                    zip(cells, [cell[0] for cell in row], [self.parse_rgb_to_hex(rgb=cell[2], appl=2) for cell in row],
+                        [self.parse_cell_align(align=cell[3]) for cell in row]):
+                if isinstance(cell_string, str):
+                    # Directly insert base strings
+                    c.paragraphs[0].add_run(cell_string).font.color.rgb = RGBColor.from_string(f"{font_color}")
+                    c.paragraphs[0].alignment = alignment
+
+                elif isinstance(cell_string, argMultiFontStringHelper):
+                    # Handle multi-font string helpers
+                    self.generate_multi_font_string(cell_string, c.paragraphs[0])
+
+        # Apply colours to cells
+        color_list = self.parse_colors(headers=headers, rows=rows)
+        for row_num, row_color in enumerate(color_list):
+            for cell_num, cell_color in enumerate(row_color):
+                table.rows[row_num].cells[cell_num]._tc.get_or_add_tcPr().append(
+                    parse_xml(rf'<w:shd {nsdecls("w")} w:fill="{cell_color}"/>'))
+
+        # Apply vertical alignment to cells:
+        vertical_alignment = self.parse_vertical_alignment(headers=headers, rows=rows)
+        for row_num, row_va in enumerate(vertical_alignment):
+            for cell_num, cell_va in enumerate(row_va):
+                table.rows[row_num].cells[cell_num]._tc.get_or_add_tcPr().append(
+                    parse_xml(rf'<w:vAlign {nsdecls("w")} w:val="{cell_va}"/>'))
+
+        # Create table caption depending on its type
+        if caption_string is not None:
+            if isinstance(caption_string, str):
+                # Directly insert base strings
+                caption = self.add_caption("Table", caption_string)
+                caption.alignment = WD_ALIGN_PARAGRAPH.CENTER
+
+            elif isinstance(caption_string, argMultiFontStringHelper):
+                # Handle multi-font string helpers
+                caption = self.add_caption("Table", "")
+                caption.alignment = WD_ALIGN_PARAGRAPH.CENTER
+
+                # Append Word runs created from multi-font string
+                caption_string.execute_backend(caption)
+
+            else:
+                # Insert blank paragraph to ensure table is closed
+                self.Report.add_paragraph()
+        else:
+            # Insert blank paragraph to ensure table is closed
+            self.Report.add_paragraph()
+
+    def add_hyperlink(self, data: dict) -> None:
+        """ Add hyperlink to the report
+        """
+        path = data.get('path', None)
+        hyperlink_string = data.get('hyperlink_string', None)
+        par = self.Report.add_paragraph()
+        self.add_hyperlink_to_paragraph(paragraph=par, url=path, text=hyperlink_string)
+
     def add_type_caption(self, caption_type, caption_string):
         """Add table caption
         """
@@ -667,6 +802,11 @@ class argWordBackend(argBackendBase):
                 # Create subsection
                 self.add_subsection(item)
 
+            # Handle subsubsection case
+            elif item_type.startswith("subsubsection"):
+                # Create subsubsection
+                self.add_subsubsection(item)
+
             # Handle paragraph case
             elif item_type == "paragraph":
                 # Add paragraph to the report
@@ -707,8 +847,13 @@ class argWordBackend(argBackendBase):
 
             # Handle aggregate case
             elif item_type == "aggregate":
-                # Execute aggregate operation
-                argAggregate.arg_aggregate(self, item)
+                # Append aggregated information
+                self.add_aggregation(item)
+
+            # Handle color-table
+            elif item_type == "color-table":
+                # Append color-table
+                self.add_color_table(data=item)
 
             # Proceed with recursion if needed
             if "sections" in item:
@@ -722,7 +867,7 @@ class argWordBackend(argBackendBase):
         super().assemble(report_map, version)
 
         # Create report with preamble
-        print("[{}] Creating Word report".format(app))
+        print("[argWordBackend] Generating Word report")
         self.create_document_preamble(version)
 
         # Pass over data for report contents
@@ -735,19 +880,19 @@ class argWordBackend(argBackendBase):
         self.add_header_numbering()
 
         # Create Word report
-        print("[{}] Saving Word report".format(app))
+        print("[argWordBackend] Saving Word report")
         self.Report.save("{}.docx".format(os.path.join(
             self.Parameters.OutputDir,
             self.Parameters.FileName)))
 
         # Update tables of contents, figures, tables on Windows only for now
-        if osn == "nt":
+        if self.osn == "nt":
             self.update_tocs(r"{}.docx".format(os.path.abspath(os.path.join(
                 self.Parameters.OutputDir,
                 self.Parameters.FileName))))
         else:
             print("*  WARNING: Table of contents not automatically generated yet by Word backend on {} systems.".format(
-                osn))
+                self.osn))
 
     def add_document_provenance(self, version=None):
         """Add document provenance information on a new page
@@ -819,7 +964,7 @@ class argWordBackend(argBackendBase):
         doc.Close(SaveChanges=True)
         word.Quit()
 
-    def add_table_of_contents(self, heading_run=None, body_run=None, lvls="1-3"):
+    def add_table_of_contents(self, heading_run=None, body_run=None, lvls="1-4"):
         """Add table of contents
         """
 
@@ -848,7 +993,7 @@ class argWordBackend(argBackendBase):
         instrText.set(qn('xml:space'), 'preserve')
 
         # Add level 1 to level 3 contents
-        instrText.text = "TOC \\o {} \\h \\z \\u".format(lvls)  # change 1-3 depending on heading levels you need
+        instrText.text = "TOC \\o {} \\h \\z \\u".format(lvls)  # change 1-4 depending on heading levels you need
 
         # Add a separate character
         fldChar2 = OxmlElement('w:fldChar')
@@ -957,3 +1102,114 @@ class argWordBackend(argBackendBase):
             hx.text = "{} {}".format(
                 hStr,
                 hx.text)
+
+    def parse_colors(self, headers: list, rows: list, appl: str = 'background') -> list:
+        """ Parses colors for whole table
+        """
+        colr = {'background': 1, 'foreground': 2}
+        ct = colr.get(appl)
+
+        headers_colors = [header[ct] for header in headers]
+        rows_colors = [[cell[ct] for cell in row] for row in rows]
+        table_colors = list()
+        table_colors.append(headers_colors)
+        table_colors.extend(rows_colors)
+        table_colors_hex = [[self.parse_rgb_to_hex(color, ct) for color in color_row] for color_row in table_colors]
+        return table_colors_hex
+
+    def support_string(self, item: dict) -> None:
+        """ Function created in order not to DRY
+        """
+        # Retrieve provided string
+        string = item["string"]
+
+        # Distinguish between plain and multi-font strings
+        if isinstance(string, argMultiFontStringHelper):
+            # Insert string into the report
+            self.generate_multi_font_string(
+                string, self.Report.add_paragraph())
+        else:
+            # Directly insert Word fragment into the report
+            self.Report.add_paragraph(string)
+
+    @staticmethod
+    def parse_vertical_alignment(headers: list, rows: list) -> list:
+        """ Parses vertical alignment for whole table
+        """
+        va_dict = {'c': 'center', 't': 'top', 'b': 'bottom'}
+        headers_va = [header[4] for header in headers]
+        rows_va = [[cell[4] for cell in row] for row in rows]
+        v_a = list()
+        v_a.append(headers_va)
+        v_a.extend(rows_va)
+        table_va = [[va_dict.get(cell_va, 'center') for cell_va in va_row] for va_row in v_a]
+        return table_va
+
+    @staticmethod
+    def parse_rgb_to_hex(rgb: str, appl: int) -> str:
+        """ Parses RGB color to HEX
+        """
+        if rgb == '' and appl == 1:
+            return 'FFFFFF'
+        elif rgb == '' and appl == 2:
+            return '000000'
+        else:
+            hex_str = ''.join(
+                [hex(int(color))[2:].upper() if len(hex(int(color))[2:]) > 1 else f"0{hex(int(color))[2:].upper()}"
+                 for color in rgb.split(',')])
+            return hex_str
+
+    @staticmethod
+    def parse_cell_align(align: str) -> str:
+        """ Parses alignment letter (c, l ,r) to paragrapth alignment
+        """
+        al_dict = {'c': WD_ALIGN_PARAGRAPH.CENTER, 'r': WD_ALIGN_PARAGRAPH.RIGHT, 'l': WD_ALIGN_PARAGRAPH.LEFT}
+        return al_dict.get(align, WD_ALIGN_PARAGRAPH.CENTER)
+
+    @staticmethod
+    def add_hyperlink_to_paragraph(paragraph, url, text, color=None, underline=None):
+        """
+        A function that places a hyperlink within a paragraph object.
+
+        :param paragraph: The paragraph we are adding the hyperlink to.
+        :param url: A string containing the required url
+        :param text: The text displayed for the url
+        :param color: The color displayed for the url
+        :param underline: The underline for the url
+        :return: The hyperlink object
+        """
+
+        # This gets access to the document.xml.rels file and gets a new relation id value
+        part = paragraph.part
+        r_id = part.relate_to(url, docx.opc.constants.RELATIONSHIP_TYPE.HYPERLINK, is_external=True)
+
+        # Create the w:hyperlink tag and add needed values
+        hyperlink = docx.oxml.shared.OxmlElement('w:hyperlink')
+        hyperlink.set(docx.oxml.shared.qn('r:id'), r_id, )
+
+        # Create a w:r element
+        new_run = docx.oxml.shared.OxmlElement('w:r')
+
+        # Create a new w:rPr element
+        rPr = docx.oxml.shared.OxmlElement('w:rPr')
+
+        # Add color if it is given
+        if color is not None:
+            c = docx.oxml.shared.OxmlElement('w:color')
+            c.set(docx.oxml.shared.qn('w:val'), color)
+            rPr.append(c)
+
+        # Remove underlining if it is requested
+        if underline is not None:
+            u = docx.oxml.shared.OxmlElement('w:u')
+            u.set(docx.oxml.shared.qn('w:val'), 'single')
+            rPr.append(u)
+
+        # Join all the xml elements together add add the required text to the w:r element
+        new_run.append(rPr)
+        new_run.text = text
+        hyperlink.append(new_run)
+
+        paragraph._p.append(hyperlink)
+
+        return hyperlink
